/**
  ******************************************************************************
  * @file    Key_scan.c
  * @author  sinomcu.com-AE
  * @brief   key scan
  *  
  *      This file provides functions to scan GPIO KEY;
  *     
  ******************************************************************************
  * @attention 
  *               DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */

#include "Key_scan.h"

Key_Config Key_Buf[KEY_NUM];      /*ȫֶ*/

/**
  * @brief  Read key pin status.
  * @param  Key_Init,need port and pin information
  * @retval An BitAction enumeration value:
  *          - Bit_RESET: Key pin is low level
  *          - Bit_SET: Key pin is high level
  */
static BitAction KEY_ReadPin(Key_Init Key){ /*ȡ*/
  return (BitAction)MS32_GPIO_IsInputPinSet(Key.GPIOx,Key.GPIO_Pin_x);
}

/**
  * @brief  Key_Config instance initialization.
  * @param  Key_Init pointer
  * @retval none
  */
void Creat_Key(Key_Init* Init) {  /*ťĳʼԸֵ*/
  uint8_t i; 
  MS32_GPIO_InitTypeDef  GPIO_InitStruct[KEY_NUM];

  for(i = 0;i < KEY_NUM;i++) {
    Key_Buf[i].Key = &Init[i];    
    MS32_GPIO_StructInit(&GPIO_InitStruct[i]);
    GPIO_InitStruct[i].Pin = Key_Buf[i].Key->GPIO_Pin_x;   /*趨*/      
    GPIO_InitStruct[i].Mode = Key_Buf[i].Key->GPIO_Mode;   /*趨ģʽ*/
    GPIO_InitStruct[i].Speed = Key_Buf[i].Key->GPIO_Speed; /*趨*/
    GPIO_InitStruct[i].Pull = Key_Buf[i].Key->GPIO_Pull;   /*趨*/
    MS32_GPIO_Init(Key_Buf[i].Key->GPIOx, &GPIO_InitStruct[i]);      /*ʼ*/

    /* ʼť״̬*/
    Key_Buf[i].Status.KEY_SHIELD = ENABLE;
    Key_Buf[i].Status.KEY_Debounce_Count =0;
    Key_Buf[i].Status.KEY_LONG_COUNT = 0;
    Key_Buf[i].Status.KEY_LEVEL = Bit_RESET;

    if(Key_Buf[i].Key->GPIO_Pull == MS32_GPIO_PULL_UP)     /*ģʽиֵ*/
      Key_Buf[i].Status.KEY_DOWN_LEVEL = Bit_RESET;
    else
      Key_Buf[i].Status.KEY_DOWN_LEVEL = Bit_SET;

    Key_Buf[i].Status.KEY_STATUS = KEY_NULL;
    Key_Buf[i].Status.KEY_PRE_EVENT = KEY_NULL;
    Key_Buf[i].Status.KEY_CUR_EVENT = KEY_NULL;
    Key_Buf[i].Status.READ_PIN = KEY_ReadPin;              /*ֵȡ*/
  }
}

/**
  * @brief  Pin voltage level to Key_Config instance key status virtually value.
  * @param  none,effect golbal Key_buff KEY_LEVEL member
  * @retval none
  */
static void Get_Key_Level(void) { /*ʵʰ°ťĵƽȥĽ*/
  uint8_t i;
  
  for(i = 0;i < KEY_NUM;i++) {
    if(Key_Buf[i].Status.KEY_SHIELD == DISABLE)
      continue;
    
    if(Key_Buf[i].Status.READ_PIN(*Key_Buf[i].Key) == Key_Buf[i].Status.KEY_DOWN_LEVEL)
      Key_Buf[i].Status.KEY_LEVEL = Bit_SET;     /*Press dowm*/
    else
      Key_Buf[i].Status.KEY_LEVEL = Bit_RESET;   /*release*/
  }
}

/**
  * @brief  Key dispose state machine.
  * @param  none
  * @retval none,effect golbal Key_buff KEY_LEVEL and KEY_CUR_EVENT member
  */
void ReadKeyStatus(void) {
  uint8_t i;
  
  Get_Key_Level();
  
  for(i = 0;i < KEY_NUM;i++) {
    switch(Key_Buf[i].Status.KEY_STATUS) {
      /*״̬0ûа*/
      case KEY_NULL:
        if(Key_Buf[i].Status.KEY_LEVEL == Bit_SET) {       /*а*/
          Key_Buf[i].Status.KEY_STATUS = KEY_DEBOUNCE;     /*ת״̬1*/
          Key_Buf[i].Status.KEY_CUR_EVENT = KEY_NULL;      /*¼*/
          Key_Buf[i].Status.KEY_Debounce_Count =0;         /**/
          Key_Buf[i].Status.KEY_LONG_COUNT = 0;            /**/    
        }
        else {
          Key_Buf[i].Status.KEY_CUR_EVENT = KEY_NULL;          /*άԭ״̬,¼*/
        }
        break;
      /*״̬1ȷ,*/
      case KEY_DEBOUNCE:
        if(Key_Buf[i].Status.KEY_LEVEL == Bit_SET) {       /*ȷϺϴͬ*/
          Key_Buf[i].Status.KEY_Debounce_Count++;
          if(Key_Buf[i].Status.KEY_Debounce_Count == KEY_DEBOUNCE_NUM) {
            Key_Buf[i].Status.KEY_Debounce_Count =0;       /**/
            Key_Buf[i].Status.KEY_LONG_COUNT = KEY_DEBOUNCE_NUM;/*ֵ*/
            Key_Buf[i].Status.KEY_STATUS = KEY_DOWN;       /*ת״̬2*/
            Key_Buf[i].Status.KEY_CUR_EVENT = KEY_DOWN;    /*¼*/
          }
        }
        else {
          Key_Buf[i].Status.KEY_Debounce_Count =0;         /**/
          Key_Buf[i].Status.KEY_STATUS = KEY_NULL;         /*ת״̬0*/
          Key_Buf[i].Status.KEY_CUR_EVENT = KEY_NULL;      /*¼*/   
        }
        break;
      /*״̬2ȷϰ,״̬3*/
      case KEY_DOWN:
      case KEY_LONG:
        if(Key_Buf[i].Status.KEY_LEVEL != Bit_SET) {       /*ͷţ˿ڸߵƽ*/
          Key_Buf[i].Status.KEY_STATUS = KEY_NULL;         /*ת״̬0*/
          Key_Buf[i].Status.KEY_CUR_EVENT = KEY_UP;        /*ɿ¼*/
          Key_Buf[i].Status.KEY_LONG_COUNT = 0;            /**/         
        }
        /*KEY_LONG_DOWN_DELAYûͷ,Ч*/
        else if(Key_Buf[i].Status.KEY_LEVEL == Bit_SET) {
          Key_Buf[i].Status.KEY_LONG_COUNT++;
          if(Key_Buf[i].Status.KEY_LONG_COUNT >= KEY_LONG_DOWN_DELAY) {
            Key_Buf[i].Status.KEY_STATUS = KEY_LONG;       /*ת״̬3*/
            Key_Buf[i].Status.KEY_CUR_EVENT = KEY_LONG;    /*¼*/
            Key_Buf[i].Status.KEY_LONG_COUNT = 0;          /**/
          }
        }
        else {
          Key_Buf[i].Status.KEY_CUR_EVENT = KEY_NULL;      /*¼*/
          Key_Buf[i].Status.KEY_LONG_COUNT = 0;            /**/
        }
        break;
      default:
        break;
    }
  }
}

/******************************** END OF FILE *********************************/
