/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-AE
  * @brief          : Main program body
  *    
  *          This file provides example code for UART LIN slave(BaudRate <20K).
  * LED1 control by LIN message,LED2 blink period 1S.
  * For details, see "readme.txt"    
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */  
#include "system_define.h"

#define LED_BLINK_HALF_PRE        50  /*uint 10ms*/

uint8_t LIN_Recv_buff[LIN_RECV_DATA_LEN] = {0x00};         /*include PID*/
uint8_t LIN_Send_buff[LIN_SEND_DATA_LEN] = {0x00};

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{
  uint8_t LED_count;

  sysclk_init();        /*sysclk 48M,HSI/2 *12;if not call this function,default HSI 8M*/ 
  SystemCoreClockUpdate();
  
  sys_tick_init();
  gpio_init();

  MS32_RCC_SetUSARTClockSource(MS32_RCC_USART1_CLKSOURCE_HSI);  /*uart clk HSI 8M*/ 
  usart1_lin_slave_init(LIN_BAUD_RATE);

  LinInit();

  Start_10MS_SF_Timer();
  
  while (1) {
    if(Get_State_10MS_SF_Timer() == SF_TIMER_OV) {
      Start_10MS_SF_Timer();
      
      LIN_RecvDataProcess();
      Upata_SendBuff();

      LED_count++;
      if( LED_count ==LED_BLINK_HALF_PRE) {
        LED_count =0;
        LED2_TOGGLE();
      }
    }
  }
}

/**
  * @brief  SystemClock_Config HSI/2 to PLL*12 sysclk 48M
  * @param  None
  * @retval None
  */
void sysclk_init(void) {
  MS32_RCC_OscInitTypeDef osc_cfg;
  MS32_RCC_PllInitTypeDef pll_cfg;
  MS32_RCC_ClkInitTypeDef clk_cfg;

  // get and clear reset flag 
  MS32_RCC_GetResetFlag(ENABLE);
  
  // osc config 
  osc_cfg.HSIState = MS32_RCC_HSI_ON;
  osc_cfg.HSEState = MS32_RCC_HSE_OFF;
  osc_cfg.LSIState = MS32_RCC_LSI_OFF;
  osc_cfg.LSEState = MS32_RCC_LSE_OFF;
  MS32_RCC_OscConfig(&osc_cfg);
  
  // pll config 
  pll_cfg.PLLState  = MS32_RCC_PLL_ON;
  pll_cfg.PLLSource = MS32_RCC_PLL_SOURCE_HSI_DIV_2;       // HSI/2 4M
  pll_cfg.PLLMUL    = MS32_RCC_PLL_MUL12;
  pll_cfg.PREDIV    = MS32_RCC_PLL_PREDIV_DIV1;
  MS32_RCC_PllConfig(&pll_cfg);
  
  // sysclk config 
  clk_cfg.SYSCLKSource   = MS32_RCC_SYSCLK_SOURCE_PLL;
  clk_cfg.AHBCLKDivider  = MS32_RCC_SYSCLK_DIV1;
  clk_cfg.APB1CLKDivider = MS32_RCC_HCLK_DIV1;
  MS32_RCC_ClockConfig(&clk_cfg);
}

/******************************** END OF FILE *********************************/
