/**
  ******************************************************************************
  * @file     LIN_user.c
  * @author   sinomcu.com-AE
  * @brief    LIN slalve,receive master sand answer data and dispose message,send
  *     back slave answer data.
  *    
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */

#include "ms32f0xx.h"
#include "user_config.h"
#include "LIN_user.h"

extern uint8_t LIN_Recv_buff[]; 
extern uint8_t LIN_Send_buff[]; 
LIN_Frame LIN_slave_frame = {UNCONDITOPMAL_FRAME,NO_ERROR,RESET,LIN_Recv_buff};
LINStatus LIN_bus_stauts =BUS_IDEL;

/**
  * @brief initial lin arguments
  * @param  
  * @retval
  */ 
void LinInit(void) {
  LIN_slave_frame.lin_frame_type =UNCONDITOPMAL_FRAME;
  LIN_slave_frame.lin_frame_error=NO_ERROR;
  LIN_slave_frame.lin_dispose_requset =RESET;
  LIN_slave_frame.recv_buff =LIN_Recv_buff;
  LIN_bus_stauts =BUS_IDEL;
}

/**
  * @brief process reviced answer data and check PID,compare checksum
  * @param  
  * @retval
  */
void LIN_RecvDataProcess(void) {
  uint8_t id=0,pid=0;
  if( LIN_slave_frame.lin_dispose_requset ==SET) {    /*recive new frame*/
    LIN_slave_frame.lin_dispose_requset =RESET;
    pid=LIN_slave_frame.recv_buff[0];
    id=GET_ID(pid);
    if(id == LIN_RECV_ANSWER_FID) {                   /*FID need dispose*/
      if( LIN_CheckPID(pid) ==RESET) {                               /*check pid error*/
        LIN_slave_frame.lin_frame_error |= PID_ERROR;
      }

      if( LIN_CompareChecksum(LIN_slave_frame.recv_buff ) ==RESET) { /*chechsum error*/
        LIN_slave_frame.lin_frame_error |= CHECKSUM_ERROR;
      }

      if( LIN_slave_frame.lin_frame_error == NO_ERROR) {             /*fram correct,data dispose*/
        if( LIN_slave_frame.recv_buff[LIN_RECV_DATA_POS] ==LIN_RECV_DATA_ID) {
          LED1_TOGGLE();
        }
      }else {                                                        /*frame error*/
        LIN_slave_frame.lin_frame_error = NO_ERROR;
        /*frame error*/
      }
    }
  }
}

/**
  * @brief updata send buff
  * @param  
  * @retval
  */
void Upata_SendBuff(void) {
  if(Get_LED1Status()==SET) {     /*SET:LED ON*/  
    LIN_Send_buff[LIN_SEND_DATA_POS] =LED_ON_SEND_DATA;
  }else{                          /*RESET:LED OFF*/
    LIN_Send_buff[LIN_SEND_DATA_POS] =LED_OFF_SEND_DATA;   
  }
}

/**
  * @brief send answer data
  * @param  
  * @retval
  */
void LIN_SendAnswer(void) {
  uint8_t send_count=0,checksum=0;

  for(send_count=0;send_count<LIN_FRAM_DATA_LEN ;send_count++) {     /*send answer data*/
    MS32_USART_TransmitData8(USART1,LIN_Send_buff[send_count]);
    while(MS32_USART_IsActiveFlag_TC(USART1)==RESET);
  }

  checksum =LIN_CaclChecksum(LIN_CaclPID(LIN_SEND_ANSWER_FID),LIN_Send_buff);
  MS32_USART_TransmitData8(USART1,checksum);     /*send check sum*/
  while(MS32_USART_IsActiveFlag_TC(USART1)==RESET);
}

/**
  * @brief  Function called in USART IT Handler
  * @param  
  * @retval 
  */
void USART_LBD_Callback(void) {
  LIN_bus_stauts =LIN_SYSNC;
  if( MS32_USART_IsActiveFlag_RXNE(USART1) ) {
    MS32_USART_ReceiveData8(USART1);
  }
  MS32_USART_EnableIT_RXNE(USART1);              /*after Break Field?Revice sysnc segment*/
} 

/**
  * @brief  Function called in USART IT Handler
  * @param  
  * @retval 
  */
void USART_RXNE_Callback(void) {
  uint8_t recv_char=0;
  static uint8_t recv_count=0;
  /*Read Received character. RXNE flag is cleared by reading of RDR register */ 
  recv_char = MS32_USART_ReceiveData8(USART1);

  switch(LIN_bus_stauts) {
    case LIN_SYSNC:               /*sysnc segment*/
      if(recv_char ==LIN_SYNC_CHAR) {
        LIN_bus_stauts =LIN_PID;
        recv_count=0;
      }else{ 
        LIN_slave_frame.lin_frame_error =SYSNC_ERROR;
      }
      break;
    case LIN_PID:                 /*PID segment*/
      if( LIN_RECV_ANSWER_FID == GET_ID(recv_char)) {      /*master send answer data*/
        LIN_slave_frame.recv_buff[recv_count++] =recv_char;     /*save PID to receive buff*/
        LIN_bus_stauts =  LIN_ANSWER;        
      } else if(LIN_SEND_ANSWER_FID ==GET_ID(recv_char)) { /*need slave send answer data*/
        LIN_SendAnswer();
        LIN_bus_stauts =LIN_WAIT_NEXT;
      } else {                                             /*other slave send answer data*/
        LIN_bus_stauts =LIN_WAIT_NEXT;
      }
      break;      
    case LIN_ANSWER:             /*receive master send answer data*/
      LIN_slave_frame.recv_buff[recv_count++] =recv_char;
      if(recv_count ==LIN_RECV_DATA_LEN) {                  /*frame end*/
        LIN_bus_stauts =LIN_WAIT_NEXT;
        LIN_slave_frame.lin_dispose_requset =SET;
      }
      break;      
    default :
      LIN_bus_stauts =LIN_WAIT_NEXT;
  }

  if(LIN_bus_stauts ==LIN_WAIT_NEXT) {                     /*wait next LBD*/
    MS32_USART_DisableIT_RXNE(USART1);
    LIN_bus_stauts =BUS_IDEL; 
  }
}

/******************************** END OF FILE *********************************/